@@ -36,31 +36,30 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-gTestfile = '15.7.3.3-4.js';
+gTestfile = '15.7.3.5-3.js';
 
 /**
-   File Name:          15.7.3.3-4.js
-   ECMA Section:       15.7.3.3 Number.MIN_VALUE
+   File Name:          15.7.3.5-3.js
+   ECMA Section:       15.7.3.5 Number.NEGATIVE_INFINITY
    Description:        All value properties of the Number object should have
    the attributes [DontEnum, DontDelete, ReadOnly]
 
-   this test checks the DontEnum attribute of Number.MIN_VALUE
+   this test checks the ReadOnly attribute of Number.NEGATIVE_INFINITY
 
    Author:             christine@netscape.com
    Date:               16 september 1997
 */
 
-
-var SECTION = "15.7.3.3-4";
+var SECTION = "15.7.3.5-3";
 var VERSION = "ECMA_1";
 startTest();
+var TITLE   = "Number.NEGATIVE_INFINITY";
 
-writeHeaderToLog( SECTION + " Number.MIN_VALUE:  DontEnum Attribute");
+writeHeaderToLog( SECTION + " "+TITLE);
 
 new TestCase( SECTION,
-	      "var string = ''; for ( prop in Number ) { string += ( prop == 'MIN_VALUE' ) ? prop : '' } string;",
-	      "",
-	      eval("var string = ''; for ( prop in Number ) { string += ( prop == 'MIN_VALUE' ) ? prop : '' } string;")
-  );
+	      "Number.NEGATIVE_INFINITY=0; Number.NEGATIVE_INFINITY",
+	      -Infinity,
+	      eval("Number.NEGATIVE_INFINITY=0; Number.NEGATIVE_INFINITY") );
 
 test();
